# HerdingCATs 🐈‍⬛

[![codecov](https://codecov.io/gh/CHRISCARLON/Herding-CATs/graph/badge.svg?token=Y9Z0QA39S3)](https://codecov.io/gh/CHRISCARLON/Herding-CATs)

Documentation📚 => [HERE](https://chriscarlon.github.io/herding-cats/)

> [!NOTE]  
> Version 0.1.0 PyPi coming soon.
>
> Herding-CATs is currently under active development.
>
> Features may change as the project evolves.
>
> Due to slight variations in how organisations set up and deploy their open data catalogues, methods may not work 100% of the time for all catalogues.
>
> We will do our best to ensure that most methods work across all catalogues and that a good variety of data catalogues is present.

---

**The aim of this project is simple...**

Speed up how data analysts explore and interact with open data sources.

- Navigate the open data ecosystem
- Find the data that you need
- Get that data into a format and/or location for further analysis

**PyPi package coming soon.**

```bash
pip install HerdingCats
```

or

```bash
poetry add HerdingCats
```

---

## Contributing

Contributions are welcome! Please feel free to submit a PR.

For major changes, please open an issue first to discuss what you would like to change.
